==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/app/controllers/spirit_hub/favorites_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class FavoritesController < ApplicationController
    include Datatablable

    before_action :find_models, only: %i[index sort]

    def index
      authorize(Favorite, policy_class:)

      @counts = SpiritHub::FavoritesCounts.new(@user).counts

      respond_to(&:html)
    end

    def sort
      authorize(Favorite, policy_class:)

      render partial: 'spirit_hub/favorites/table'
    end

    def remove
      tagset = policy_scope(Tagset, policy_scope_class:).find_by(id: params[:id])
      authorize(tagset, policy_class:)

      if Favorite.where(user: @user, tagset:).destroy_all
        set_user_favorites
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de la suppression du favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      @user_favorites = Favorite.where(user_id: @user.id).pluck(:tagset_id).flatten.uniq.compact
      scope = policy_scope(Tagset, policy_scope_class:).where(:id.in => @user_favorites)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/controllers/spirit_hub/favorites_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class FavoritesController < ApplicationController
    include Datatablable

    before_action :find_models, only: %i[index sort]

    def index
      authorize(Favorite, policy_class:)

      @counts = SpiritHub::FavoritesCounts.new(@user).counts

      respond_to(&:html)
    end

    def sort
      authorize(Favorite, policy_class:)

      render partial: 'spirit_hub/favorites/table'
    end

    def remove
      tagset = policy_scope(Tagset, policy_scope_class:).find_by(id: params[:id])
      authorize(tagset, policy_class:)

      if Favorite.where(user: @user, tagset:).destroy_all
        set_user_favorite_tagset_ids
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, FlashMessagesComponent.new(flash)),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de la suppression du favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, FlashMessagesComponent.new(flash))
        ]
      end
    end

    private

    def find_models
      @user_favorite_tagset_ids = Favorite.where(user_id: @user.id).pluck(:tagset_id).flatten.uniq.compact
      scope = policy_scope(Tagset, policy_scope_class:).where(:id.in => @user_favorite_tagset_ids)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end
